@@ -1319,17 +1319,17 @@ class Builder(Update):
             if path.exists(dbPkg) and path.exists(pkgDir):
                 # get pkg list from distro
                 pkgList = reduce(lambda x, y: x + y,
-                    ((path.join(x, "%s.tbz2" % z) for z 
-                        in os.listdir(path.join(dbPkg, x))) for x 
-                            in os.listdir(dbPkg)),  
+                    [[path.join(x, "%s.tbz2" % z) for z 
+                        in os.listdir(path.join(dbPkg, x))] for x 
+                            in os.listdir(dbPkg)],  
                     [])
                 # get binary packages
                 binList = reduce(lambda x, y: x + y,
-                    ((path.join(x, y)[len(pkgDir) + 1:] for y 
-                        in os.listdir(path.join(x))) for x 
+                    [[path.join(x, y)[len(pkgDir) + 1:] for y 
+                        in os.listdir(path.join(x))] for x 
                         in (z for z in (path.join(pkgDir, o) for o 
                         in os.listdir(pkgDir)) 
-                        if path.isdir(z))),
+                        if path.isdir(z))],
                     [])
                 # remove files which in binary and not in db/pkg
                 removeList = list(set(binList) - set(pkgList))
